@@ -49,6 +49,9 @@ import relex.tree.PhraseTree;
  * 5. A TruthValue (inherited from Atom) that ranks the relative
  *    likelihood of this parse of being a correct (meaningful) parse
  *    of the sentence.
+ *
+ * XXX Most or all of this data should probably be anchored in the 
+ * feature-node graph.
  */
 public class ParsedSentence
 	extends Atom
@@ -75,10 +78,6 @@ public class ParsedSentence
 
 	private String errorString;
 
-	// Metadata about the sentence; primarily, this consists of diagnostic
-	// info returned by the link grammar parser.
-	private FeatureNode metaData;
-
 	// An ArrayList of FeatureNodes, each one representing a word in the
 	// sentence.  If there are no "link islands", each can be reached by
 	// following arcs from the others.
@@ -96,12 +95,19 @@ public class ParsedSentence
 		leafConstituents = new ArrayList<FeatureNode>();
 	}
 
-	public void setMetaData(FeatureNode f) {
-		metaData = f;
+	public void setMetaData(FeatureNode f)
+	{
+		// Get the left wall, and anchor the meta-data there.
+		getLeft().get("wall").set("meta", f);
 	}
 
-	public FeatureNode getMetaData() {
-		return metaData;
+	/**
+	 * Return metadata about the sentence; primarily, this consists
+	 * of diagnostic info returned by the link grammar parser.
+	 */
+	public FeatureNode getMetaData()
+	{
+		return getLeft().get("wall").get("meta");
 	}
 
 	public String getOriginalSentence() {
@@ -289,7 +295,11 @@ public class ParsedSentence
 	 * which "part of speech" they are.  Thus, for example:
 	 * "The big red baloon floated away." becomes
 	 * LEFT-WALL The.det big.adj red.adj balloon.noun float.verb away.prep .
+	 *
+	 * @deprecated -- please make use of the output systems in the 
+	 * output directory, or create one, if you really need it!
 	 */
+	@Deprecated
 	public String printPartsOfSpeech()
 	{
 		StringBuffer sb = new StringBuffer();
@@ -299,9 +309,6 @@ public class ParsedSentence
 			String pos = w.getPOS();
 			if (pos != null && !pos.equals("WORD"))
 				sb.append("." + pos);
-			String tense = w.getTenseVal();  // ??? tense is not working ...
-			if (tense != null && tense.length() > 0)
-				sb.append(tense);
 			if (i < leafConstituents.size() - 1)
 				sb.append(" ");
 			// else
@@ -376,7 +383,7 @@ public class ParsedSentence
 
 	private int getMeta(String str)
 	{
-		FeatureNode fn = metaData.get(str);
+		FeatureNode fn = getMetaData().get(str);
 		if (fn == null) return -1;
 		String val = fn.getValue();
 		return Integer.parseInt(val);
