@@ -90,6 +90,7 @@ public class RelationExtractor
 
 	/** Penn tree-bank style phrase structure markup. */
 	private PhraseMarkup phraseMarkup;
+	public boolean do_tree_markup;
 
 	/** Anaphora resolution */
 	// XXX these should probably be moved to class Document!
@@ -103,6 +104,12 @@ public class RelationExtractor
 	/* Stanford parser compatibility mode */
 	public boolean do_stanford;
 
+	/* Penn tagset compatibility mode */
+	public boolean do_penn_tagging;
+
+	/* Expand preposition markup to two dependencies. */
+	public boolean do_expand_preps;
+
 	/** Statistics */
 	private ParseStats stats;
 
@@ -138,14 +145,18 @@ public class RelationExtractor
 
 		doco = new Document();
 
+		do_tree_markup = false;
+
 		do_stanford = false;
+		do_penn_tagging = false;
+		do_expand_preps = false;
 
 		stats = new ParseStats();
 		sumtime = new TreeMap<String,Long>();
 		cnttime = new TreeMap<String,Long>(); 
 	}
 
-	String getVersion()
+	public String getVersion()
 	{
 		return parser.getVersion() + "\t" + Version.getVersion();
 	}
@@ -214,6 +225,11 @@ public class RelationExtractor
 
 			for (ParsedSentence parse : sntc.getParses())
 			{
+				if (do_expand_preps) 
+				{
+					parse.getLeft().set("expand-preps", new FeatureNode("T"));
+				}
+
 				// Markup feature node graph with entity info,
 				// so that the relex algs (next step) can see them.
 				entityMaintainer.prepareSentence(parse.getLeft());
@@ -221,17 +237,21 @@ public class RelationExtractor
 				// The actual relation extraction is done here.
 				sentenceAlgorithmApplier.applyAlgs(parse, context);
 				if (do_stanford) sentenceAlgorithmApplier.extractStanford(parse, context);
+				if (do_penn_tagging) sentenceAlgorithmApplier.pennTag(parse, context);
 
 				// Strip out the entity markup, so that when the
 				// sentence is printed, we don't print gunk.
 				entityMaintainer.repairSentence(parse.getLeft());
 
 				// Also do a Penn tree-bank style phrase structure markup.
-				phraseMarkup.markup(parse);
+				if (do_tree_markup)
+				{
+					phraseMarkup.markup(parse);
 
-				// Repair the entity-mangled tree-bank string.
-				PhraseTree pt = new PhraseTree(parse.getLeft());
-				parse.setPhraseString(pt.toString());
+					// Repair the entity-mangled tree-bank string.
+					PhraseTree pt = new PhraseTree(parse.getLeft());
+					parse.setPhraseString(pt.toString());
+				}
 			}
 
 			// Assign a simple parse-ranking score, based on LinkGrammar data.
@@ -347,6 +367,7 @@ public class RelationExtractor
 		String callString = "RelationExtractor" +
 			" [-a (perform anaphora resolution)]" +
 			" [-c (show plain output)]" +
+			" [--expand-preps (show expanded prepositions)]" +
 			" [-f (show frame output)]" +
 			" [-g (use GATE entity detector)]" +
 			" [-h (show this help)]" +
@@ -358,6 +379,7 @@ public class RelationExtractor
 			" [--pa (show phrase-based lexical chunks)]" +
 			" [--pb (show pattern-based lexical chunks)]" +
 			" [--pc (show relational lexical chunks)]" +
+			" [--penn (generate Penn treebank-style POS tags)]" +
 			" [--prolog (show prolog output)]" +
 			" [-q (do NOT show relations)]" +
 			" [-r (show raw output)]" +
@@ -369,6 +391,7 @@ public class RelationExtractor
 		HashSet<String> flags = new HashSet<String>();
 		flags.add("-a");
 		flags.add("-c");
+		flags.add("--expand-preps");
 		flags.add("-f");
 		flags.add("-g");
 		flags.add("-h");
@@ -378,6 +401,7 @@ public class RelationExtractor
 		flags.add("--pa");
 		flags.add("--pb");
 		flags.add("--pc");
+		flags.add("--penn");
 		flags.add("--prolog");
 		flags.add("-q");
 		flags.add("-r");
@@ -437,6 +461,15 @@ public class RelationExtractor
 		    (commandMap.get("-o") == null))
 		{
 			re.do_anaphora_resolution = true;
+			re.do_tree_markup = true;
+		}
+
+		if ((commandMap.get("-t") != null) ||
+		    (commandMap.get("--pa") != null) ||
+		    (commandMap.get("--pb") != null) ||
+		    (commandMap.get("--pc") != null))
+		{
+			re.do_tree_markup = true;
 		}
 
 		if (commandMap.get("--stanford") != null)
@@ -444,6 +477,16 @@ public class RelationExtractor
 			re.do_stanford = true;
 		}
 
+		if (commandMap.get("--penn") != null)
+		{
+			re.do_penn_tagging = true;
+		}
+
+		if (commandMap.get("--expand-preps") != null)
+		{
+			re.do_expand_preps = true;
+		}
+
 		EntityMaintainerFactory gem = null;
 		if (commandMap.get("-g") != null)
 		{
@@ -646,7 +689,8 @@ public class RelationExtractor
 
 					if (commandMap.get("--stanford") != null)
 					{
-						System.out.println(StanfordView.printRelations(parse));
+						System.out.println(
+							StanfordView.printRelations(parse, re.do_penn_tagging));
 						System.out.println("\n======\n");
 					}
 
@@ -708,6 +752,7 @@ public class RelationExtractor
 					System.err.println ("\n" + re.stats.toString());
 				}
 
+				if (commandMap.get("-s") != null) break;
 				sentence = ds.getNextSentence();
 			}
 			if (commandMap.get("-s") != null) break;
@@ -723,6 +768,7 @@ public class RelationExtractor
 		{
 			System.out.println(".\nexit");
 		}
+		System.exit(0);
 	}
 }
 
