@@ -161,6 +161,8 @@ public class FeatureNode extends Atom
 	 * Sets the value of this feature node. Method will fail if this FeatureNode
 	 * is not valued, by throwing RuntimeException.
 	 *
+	 * XXX this copies the string ... why ????
+	 *
 	 * @param value
 	 *            the value of this feature node
 	 */
@@ -171,7 +173,8 @@ public class FeatureNode extends Atom
 					"Cannot set the value of a non-valued FeatureNode");
 		if (value == null)
 			throw new RuntimeException("Cannot set to null value");
-		this.value = new String(value);
+		// this.value = new String(value);
+		this.value = value;
 	}
 
 	/**
@@ -298,7 +301,9 @@ public class FeatureNode extends Atom
 				{
 					throw new RuntimeException(
 						"Cannot merge two non-valued feature nodes with inconsistent features.\n" +
-						"\tSuggest using += instead of = in algs file. fName = " + fName);
+						"\tSuggest using += instead of = in algs file. fName = " + fName + "\n" +
+						"\tthis = " + thisf.get("orig_str") + "-" + thisf.get("index_in_sentence") + "\n" +
+						"\tother = " + otherf.get("orig_str") + "-" + otherf.get("index_in_sentence") + "\n");
 				}
 			}
 		}
